@@ -114,6 +114,14 @@ def snowflake_engine_factory(
             "WAREHOUSE": "SNOWFLAKE_TRANSFORM_WAREHOUSE",
             "ROLE": "TRANSFORMER",
         },
+        "SALES_ANALYTICS": {
+            "USER": "SNOWFLAKE_LOAD_USER",
+            "PASSWORD": "SNOWFLAKE_LOAD_PASSWORD",
+            "ACCOUNT": "SNOWFLAKE_ACCOUNT",
+            "DATABASE": "SNOWFLAKE_LOAD_DATABASE",
+            "WAREHOUSE": "SNOWFLAKE_LOAD_WAREHOUSE",
+            "ROLE": "SALES_ANALYTICS",
+        },
     }
 
     vars_dict = role_dict[role]
